[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- pywurfl: pywurfl - Python tools for processing and querying the Wireless Universal Resource File (WURFL)
  - pywurfl.algorithms: pywurfl search algorithms
    - pywurfl.algorithms.wurfl
      - pywurfl.algorithms.wurfl.handlers: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL.
      - pywurfl.algorithms.wurfl.normalizers: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL.
      - pywurfl.algorithms.wurfl.strategies: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL.
      - pywurfl.algorithms.wurfl.utils: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL.
  - pywurfl.exceptions: Exception Classes
  - pywurfl.ql: pywurfl Query Language
  - pywurfl.serialize: pywurfl WURFL class hierarchy serializer
  - pywurfl.wurflprocessor: WURFL processing utility.
- wurfl2python: WURFL <wurfl.sourceforge.net> conversion utility